Class: CloudmersiveDocumentaiApiClient::AdvancedExtractClassificationRequest
- Inherits:
-
Object
- Object
- CloudmersiveDocumentaiApiClient::AdvancedExtractClassificationRequest
- Defined in:
- lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb
Overview
Request to perform an AI document classification on a document
Instance Attribute Summary collapse
-
#categories ⇒ Object
Possible categories for the document.
-
#input_file ⇒ Object
Input document file to perform the operation on as a byte array.
-
#maximum_pages_processed ⇒ Object
Optional: Limit the number of pages processed.
-
#preprocessing ⇒ Object
Optional: Set the level of image pre-processing to enhance accuracy.
-
#result_cross_check ⇒ Object
Optional: Set the level of output accuracy cross-checking to perform on the input.
-
#rotate_image_degrees ⇒ Object
Optional: Rotate the input image before recognition by the specified number of degrees; valid values range from -360 to +360.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdvancedExtractClassificationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AdvancedExtractClassificationRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'InputFile') self.input_file = attributes[:'InputFile'] end if attributes.has_key?(:'Categories') if (value = attributes[:'Categories']).is_a?(Array) self.categories = value end end if attributes.has_key?(:'Preprocessing') self.preprocessing = attributes[:'Preprocessing'] end if attributes.has_key?(:'ResultCrossCheck') self.result_cross_check = attributes[:'ResultCrossCheck'] end if attributes.has_key?(:'MaximumPagesProcessed') self.maximum_pages_processed = attributes[:'MaximumPagesProcessed'] end if attributes.has_key?(:'RotateImageDegrees') self.rotate_image_degrees = attributes[:'RotateImageDegrees'] end end |
Instance Attribute Details
#categories ⇒ Object
Possible categories for the document
22 23 24 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 22 def categories @categories end |
#input_file ⇒ Object
Input document file to perform the operation on as a byte array
19 20 21 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 19 def input_file @input_file end |
#maximum_pages_processed ⇒ Object
Optional: Limit the number of pages processed
31 32 33 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 31 def maximum_pages_processed @maximum_pages_processed end |
#preprocessing ⇒ Object
Optional: Set the level of image pre-processing to enhance accuracy. Possible values are ‘Auto’, ‘SmoothEdges’, ‘SmoothEdgesPlus’, ‘Compatability’ and ‘None’. Default is Auto. Set to SmoothEdges to smooth harsh edges in the input image to enhance recognition accuracy. Set to SmoothEdgesPlus to smooth harsh edges to a higher degree. Set to Compatability for maximum PDF feature compatability.
25 26 27 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 25 def preprocessing @preprocessing end |
#result_cross_check ⇒ Object
Optional: Set the level of output accuracy cross-checking to perform on the input. Possible values are ‘None’, ‘Advanced’, ‘Ultra’ and ‘Hyper’. Default is None. Ultra and Hyper will produce the highest accuracy but at the cost of longer processing times.
28 29 30 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 28 def result_cross_check @result_cross_check end |
#rotate_image_degrees ⇒ Object
Optional: Rotate the input image before recognition by the specified number of degrees; valid values range from -360 to +360.
34 35 36 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 34 def rotate_image_degrees @rotate_image_degrees end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 37 def self.attribute_map { :'input_file' => :'InputFile', :'categories' => :'Categories', :'preprocessing' => :'Preprocessing', :'result_cross_check' => :'ResultCrossCheck', :'maximum_pages_processed' => :'MaximumPagesProcessed', :'rotate_image_degrees' => :'RotateImageDegrees' } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 49 def self.swagger_types { :'input_file' => :'String', :'categories' => :'Array<DocumentCategories>', :'preprocessing' => :'String', :'result_cross_check' => :'String', :'maximum_pages_processed' => :'Integer', :'rotate_image_degrees' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && input_file == o.input_file && categories == o.categories && preprocessing == o.preprocessing && result_cross_check == o.result_cross_check && maximum_pages_processed == o.maximum_pages_processed && rotate_image_degrees == o.rotate_image_degrees end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 172 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = CloudmersiveDocumentaiApiClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 238 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 151 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 144 def hash [input_file, categories, preprocessing, result_cross_check, maximum_pages_processed, rotate_image_degrees].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
97 98 99 100 101 102 103 104 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 97 def list_invalid_properties invalid_properties = Array.new if !@input_file.nil? && @input_file !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) invalid_properties.push('invalid value for "input_file", must conform to the pattern /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
218 219 220 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 218 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 212 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
108 109 110 111 |
# File 'lib/cloudmersive-documentai-api-client/models/advanced_extract_classification_request.rb', line 108 def valid? return false if !@input_file.nil? && @input_file !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) true end |